package demo.gps;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.location.GpsSatellite;
import android.location.GpsStatus;
import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.location.LocationProvider;
import android.os.Bundle;
import android.text.Html;
import android.util.Log;
import android.widget.TextView;

public class MainActivity extends Activity {
    
	LocationManager locManager;
	
	TextView textLatitude, 
			 textLongitude, 
			 textSpeed,
			 textMaxSatellite,
			 textSatellites;
	
	AlertDialog openGpsSettings;
	
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        
        textLatitude = (TextView)findViewById(R.id.textLatitude);
        textLongitude = (TextView)findViewById(R.id.textLongitude);
        textSpeed = (TextView)findViewById(R.id.textSpeed);
        textMaxSatellite = (TextView)findViewById(R.id.textMaxSatellite);
        textSatellites = (TextView)findViewById(R.id.textSatellites);
        
        locManager = (LocationManager)getSystemService(LOCATION_SERVICE);
    }
    
    @Override
	protected void onResume() {
    	// Feliratkozunk, tbb dologra is
		locManager.requestLocationUpdates(
				LocationManager.GPS_PROVIDER, 1000, 1, locListener);
		locManager.addGpsStatusListener(gpsStatusListener);
		locManager.addNmeaListener(nmeaListener);
		super.onResume();
	}
    
    @Override
	protected void onPause() {  
    	// Leiratkozunk, felszabadtjuk az erforrst :-)
		locManager.removeUpdates(locListener);
		locManager.removeGpsStatusListener(gpsStatusListener);
		locManager.removeNmeaListener(nmeaListener);
		super.onPause();
	}

    // -------------------- Nyers NMEA mondatok kinyerse -----------------------
    private GpsStatus.NmeaListener nmeaListener = new GpsStatus.NmeaListener() {
		public void onNmeaReceived(long timestamp, String nmea) {
			Log.d("NIK", nmea);
		}
	};

    // ------- GPS sttusz vltozs (minsg fle, pl. satelitek szma)  --------
    private GpsStatus.Listener gpsStatusListener = new GpsStatus.Listener() {
		public void onGpsStatusChanged(int event) {
			// Mholdakrl kapott informcik megvltoztak
			if(event == GpsStatus.GPS_EVENT_SATELLITE_STATUS){
				GpsStatus status = locManager.getGpsStatus(null);
				
				textMaxSatellite.setText(String.valueOf(status.getMaxSatellites()));
				textSatellites.setText("");
				// Mholdak listjn vgigmegynk
				for(GpsSatellite sat : status.getSatellites()){
					String info = sat.getPrn() + " | " + sat.getSnr() + " | " + sat.getAzimuth() + " | " + sat.getElevation() + "\n";
					// Hasznlatban, van-e az adott mhold jele a szmtsokban
					if(sat.usedInFix())
						textSatellites.append(Html.fromHtml("<b>" + info  + "</b><br />"));
					else
						textSatellites.append(info);
				}
			}
		}
	};
    
    
    // ------------------------- GPS adatok listenerje --------------------------
	private LocationListener locListener = new LocationListener() {
		// Nem GPS sttusz, hanem a szolgltats sttusza
		public void onStatusChanged(String provider, int status, Bundle extras) {
			switch(status){
				case LocationProvider.OUT_OF_SERVICE: break;
				case LocationProvider.TEMPORARILY_UNAVAILABLE: break;
				case LocationProvider.AVAILABLE: break;
			}
		}
		
		// GPS engedlyezve
		public void onProviderEnabled(String provider) {
			if(openGpsSettings != null)
				openGpsSettings.dismiss();
		}
		
		// GPS nincs engedlyezve 
		public void onProviderDisabled(String provider) {			
			if(openGpsSettings == null){
				// sszedobunk egy dialgus ablakot, hogy odamenjen-e a belltsokhoz
				AlertDialog.Builder ab = new AlertDialog.Builder(MainActivity.this);
				ab.setTitle("GPS kikapcsolva...");
				ab.setMessage("Ugrs a GPS belltsokhoz?");
				ab.setPositiveButton("Igen", new DialogInterface.OnClickListener() {
					public void onClick(DialogInterface dialog, int which) {
						Intent i = new Intent(android.provider.Settings.ACTION_LOCATION_SOURCE_SETTINGS);
						startActivity(i);
					}
				});
				ab.setNegativeButton("Kihagyom", null);
				openGpsSettings = ab.create();
			}
			openGpsSettings.show();
		}
		
		// GPS pozici rkezik
		public void onLocationChanged(Location location) {
			textLatitude.setText(String.valueOf(location.getLatitude()));
			textLongitude.setText(String.valueOf(location.getLongitude()));
			textSpeed.setText(String.valueOf(location.getSpeed()));
		}
	};
    
}